@@ -1675,8 +1675,8 @@ xfs_bmbt_disk_get_all(
 {
 	__uint64_t	l0, l1;
 
-	l0 = INT_GET(r->l0, ARCH_CONVERT);
-	l1 = INT_GET(r->l1, ARCH_CONVERT);
+	l0 = INT_GET(get_unaligned((__uint64_t *)&r->l0), ARCH_CONVERT);
+	l1 = INT_GET(get_unaligned((__uint64_t *)&r->l1), ARCH_CONVERT);
 
 	__xfs_bmbt_get_all(l0, l1, s);
 }
